=====
ctrie
=====

.. image:: https://img.shields.io/travis/bfontaine/ctrie.png
   :target: https://travis-ci.org/bfontaine/ctrie
   :alt: Build status

.. image:: https://img.shields.io/coveralls/bfontaine/ctrie/master.png
   :target: https://coveralls.io/r/bfontaine/ctrie?branch=master
   :alt: Coverage status

.. image:: https://img.shields.io/pypi/v/ctrie.png
   :target: https://pypi.python.org/pypi/ctrie
   :alt: Pypi package

.. image:: https://img.shields.io/pypi/dm/ctrie.png
   :target: https://pypi.python.org/pypi/ctrie

``ctrie`` is a compact trie implementation in Python. Its main goal is to
optimize the storage of large datasets of similar small piece of text with a
lot of common prefixes.

Install
-------

.. code-block::

    pip install ctrie

The library works with both Python 2.x and 3.x.

Usage
-----

`Read the docs`_.

.. _Read the docs: http://ctrie.readthedocs.org/en/latest/
